@@ -608,7 +608,7 @@ handle_msg(#ssh_msg_channel_open{channel_type = "forwarded-tcpip",
                        suggest_window_size = WinSz,
                        suggest_packet_size = PktSz,
                        options = Options,
-                       sub_system_supervisor = SubSysSup
+                       connection_supervisor = ConnectionSup
                       } = C,
 	   client, _SSH) ->
     {ReplyMsg, NextChId} =
@@ -616,7 +616,7 @@ handle_msg(#ssh_msg_channel_open{channel_type = "forwarded-tcpip",
             {ok, {ConnectToHost,ConnectToPort}} ->
                 case gen_tcp:connect(ConnectToHost, ConnectToPort, [{active,false}, binary]) of
                     {ok,Sock} ->
-                        {ok,Pid} = ssh_subsystem_sup:start_channel(client, SubSysSup, self(),
+                        {ok,Pid} = ssh_connection_sup:start_channel(client, ConnectionSup, self(),
                                                                    ssh_tcpip_forward_client, ChId,
                                                                    [Sock], undefined, Options),
                         ssh_client_channel:cache_update(Cache,
@@ -666,7 +666,7 @@ handle_msg(#ssh_msg_channel_open{channel_type = "direct-tcpip",
                        suggest_window_size = WinSz,
                        suggest_packet_size = PktSz,
                        options = Options,
-                       sub_system_supervisor = SubSysSup
+                       connection_supervisor = ConnectionSup
                       } = C,
 	   server, _SSH) ->
     {ReplyMsg, NextChId} =
@@ -682,7 +682,7 @@ handle_msg(#ssh_msg_channel_open{channel_type = "direct-tcpip",
                 case gen_tcp:connect(binary_to_list(HostToConnect), PortToConnect,
                                      [{active,false}, binary]) of
                     {ok,Sock} ->
-                        {ok,Pid} = ssh_subsystem_sup:start_channel(server, SubSysSup, self(),
+                        {ok,Pid} = ssh_connection_sup:start_channel(server, ConnectionSup, self(),
                                                                    ssh_tcpip_forward_srv, ChId,
                                                                    [Sock], undefined, Options),
                         ssh_client_channel:cache_update(Cache,
@@ -914,8 +914,8 @@ handle_msg(#ssh_msg_global_request{name = <<"tcpip-forward">>,
             {[{connection_reply, request_failure_msg()}], Connection};
 
         true ->
-            SubSysSup = ?GET_INTERNAL_OPT(subsystem_sup, Opts),
-            FwdSup = ssh_subsystem_sup:tcpip_fwd_supervisor(SubSysSup),
+            ConnectionSup = ?GET_INTERNAL_OPT(connection_sup, Opts),
+            FwdSup = ssh_connection_sup:tcpip_fwd_supervisor(ConnectionSup),
             ConnPid = self(),
             case ssh_tcpip_forward_acceptor:supervised_start(FwdSup,
                                                              {ListenAddrStr, ListenPort},
@@ -1129,22 +1129,22 @@ setup_session(#connection{channel_cache = Cache,
 start_cli(#connection{options = Options, 
 		      cli_spec = CliSpec,
 		      exec = Exec,
-		      sub_system_supervisor = SubSysSup}, ChannelId) ->
+		      connection_supervisor = ConnectionSup}, ChannelId) ->
     case CliSpec of
         no_cli ->
             {error, cli_disabled};
         {CbModule, Args} ->
-            ssh_subsystem_sup:start_channel(server, SubSysSup, self(), CbModule, ChannelId, Args, Exec, Options)
+            ssh_connection_sup:start_channel(server, ConnectionSup, self(), CbModule, ChannelId, Args, Exec, Options)
     end.
 
 
 start_subsystem(BinName, #connection{options = Options,
-                                     sub_system_supervisor = SubSysSup},
+                                     connection_supervisor = ConnectionSup},
 	       #channel{local_id = ChannelId}, _ReplyMsg) ->
     Name = binary_to_list(BinName),
     case check_subsystem(Name, Options) of
 	{Callback, Opts} when is_atom(Callback), Callback =/= none ->
-            ssh_subsystem_sup:start_channel(server, SubSysSup, self(), Callback, ChannelId, Opts, undefined, Options);
+            ssh_connection_sup:start_channel(server, ConnectionSup, self(), Callback, ChannelId, Opts, undefined, Options);
         {none, _} ->
             {error, bad_subsystem};
 	{_, _} ->
